@@ -45,7 +45,7 @@ class ERColumn:
     autoincrement: bool
     unique: bool
     encrypt: bool
-    default: Optional[str] = None
+    description: str
 
 
 @dataclass
@@ -54,7 +54,8 @@ class ERRelationship:
     from_table: str
     to_table: str
     relationship_type: RelationshipType
-    name: Optional[str] = None
+    local_name: str
+    target_name: str
 
 
 @dataclass
@@ -242,11 +243,12 @@ class ERDiagramGenerator(BaseGenerator):
                         name=name,
                         type=column.type,
                         nullable=column.nullable,
-                        primary_key=column.primary_key,
+                        primary_key=column.args.primary_key,
                         foreign_key=column.is_foreign_key,
-                        autoincrement=column.autoincrement,
-                        unique=column.unique,
+                        autoincrement=column.args.autoincrement,
+                        unique=column.args.unique,
                         encrypt=column.encrypt,
+                        description=column.description
                     )
                     columns.append(er_column)
                 
@@ -280,7 +282,9 @@ class ERDiagramGenerator(BaseGenerator):
                 relationship = ERRelationship(
                     from_table=relation.local.tablename,
                     to_table=relation.target.tablename,
-                    relationship_type=relation.direction
+                    relationship_type=relation.direction,
+                    local_name=relation.name,
+                    target_name=relation.backref
                 )
                     
                 self._relationships.append(relationship)
@@ -351,22 +355,20 @@ class ERDiagramGenerator(BaseGenerator):
         if self.include_relationships:
             for rel in self._relationships:
                 # Configurar estilo según el tipo de relación
+                down_label = f'🔽 {rel.local_name}'
+                up_label = f'🔼 {rel.target_name}'
                 if rel.relationship_type == RelationshipType.ONE_TO_ONE.value:
                     arrowhead = 'dot'
                     arrowtail = 'dot'
-                    label = f'1 {rel.from_table} : 1 {rel.to_table}'
                 elif rel.relationship_type == RelationshipType.ONE_TO_MANY.value:
                     arrowhead = 'dot'
                     arrowtail = 'crow'
-                    label = f'1 {rel.from_table} : N {rel.to_table}'
                 elif rel.relationship_type == RelationshipType.MANY_TO_ONE.value:
                     arrowhead = 'crow'
                     arrowtail = 'dot'
-                    label = f'N {rel.from_table} : 1 {rel.to_table}'
                 else:  # MANY_TO_MANY
                     arrowhead = 'crow'
                     arrowtail = 'crow'
-                    label = f'N {rel.from_table} : N {rel.to_table}'
                 
                 # Crear nodo invisible intermedio
                 # Esto es para evitar que Graphviz dibuje una línea directa entre las tablas
@@ -388,12 +390,13 @@ class ERDiagramGenerator(BaseGenerator):
                 dot.edge(
                     waypoint_name,
                     rel.from_table,
+                    label=down_label,
                     arrowhead=arrowhead,
                     arrowsize='1',
                     headclip='true',
                     tailclip='true',
                     dir='forward',
-                    fontsize=str(self.themes[self.theme]['fonts']['size'] - 1),
+                    fontsize=str(self.themes[self.theme]['fonts']['size']),
                     color=self.themes[self.theme]['colors']['relationship'],
                     penwidth='1.5',
                 )
@@ -401,12 +404,13 @@ class ERDiagramGenerator(BaseGenerator):
                 dot.edge(
                     rel.to_table,
                     waypoint_name,
+                    label=up_label,
                     arrowtail=arrowtail,
                     arrowsize='1.5',
                     headclip='true',
                     tailclip='true',
                     dir='back',
-                    fontsize=str(self.themes[self.theme]['fonts']['size'] - 1),
+                    fontsize=str(self.themes[self.theme]['fonts']['size']),
                     color=self.themes[self.theme]['colors']['relationship'],
                     penwidth='1.5',
                 )
@@ -441,16 +445,18 @@ class ERDiagramGenerator(BaseGenerator):
         if entity.is_view:
             header_color = theme_config['colors']['view_header']
             icon = '👁️'
+            span = 3
         else:
             header_color = theme_config['colors']['table_header']
             icon = '📋'
+            span = 4
 
         html = '<TABLE BORDER="0" CELLBORDER="0" CELLSPACING="0" CELLPADDING="4">'
 
         # Agregar fila de encabezado con nombre de entidad
         html += (
             '<TR>'
-            f'<TD COLSPAN="3" BGCOLOR="{header_color}" BORDER="1">'
+            f'<TD COLSPAN="{span}" BGCOLOR="{header_color}" BORDER="1">'
             f'<FONT POINT-SIZE="{theme_config["fonts"]["header_size"]}" COLOR="white">'
             f'{icon} {entity.name}'
             '</FONT>'
@@ -466,7 +472,7 @@ class ERDiagramGenerator(BaseGenerator):
             current_line = ""
             
             for word in words:
-                if len(current_line + " " + word) <= 50:
+                if len(current_line + " " + word) <= 70:
                     current_line += (" " + word) if current_line else word
                 else:
                     if current_line:
@@ -478,7 +484,7 @@ class ERDiagramGenerator(BaseGenerator):
             
             html += (
                 f'<TR>'
-                f'<TD COLSPAN="3" BGCOLOR="{theme_config["colors"]["description"]}" ALIGN="LEFT" BORDER="1">'
+                f'<TD COLSPAN="{span}" BGCOLOR="{theme_config["colors"]["description"]}" ALIGN="LEFT" BORDER="1">'
                 f'<FONT POINT-SIZE="{theme_config["fonts"]["size"] - 1}" COLOR="black">'
             )
             
@@ -501,7 +507,7 @@ class ERDiagramGenerator(BaseGenerator):
             # Mostrar solo el número de columnas
             html += (
                 f'<TR>'
-                f'<TD COLSPAN="3" BGCOLOR="{theme_config["colors"]["column_alt"]}" HEIGHT="20" BORDER="1">'
+                f'<TD COLSPAN="{span}" BGCOLOR="{theme_config["colors"]["column_alt"]}" HEIGHT="20" BORDER="1">'
                 f'<FONT POINT-SIZE="{theme_config["fonts"]["size"] - 1}">'
                 f'{len(entity.columns)} columnas'
                 f'</FONT>'
@@ -571,9 +577,40 @@ class ERDiagramGenerator(BaseGenerator):
             f'{column.type.upper()}'
             f'</FONT>'
             f'</TD>'
-            f'</TR>'
+            f'{"</TR>" if is_view else ""}'
         )
 
+        if not is_view:
+            # Dividir la descripción en líneas de máximo 50 caracteres
+            description_lines = []
+            words = column.description.split()
+            current_line = ""
+            
+            for word in words:
+                if len(current_line + " " + word) <= 50:
+                    current_line += (" " + word) if current_line else word
+                else:
+                    if current_line:
+                        description_lines.append(current_line)
+                    current_line = word
+            
+            if current_line:
+                description_lines.append(current_line)
+            
+            # Generar HTML para cada línea
+            description = ''
+            for line in description_lines:
+                description += f'{line}<BR ALIGN="LEFT"/>'
+
+            row += (
+                f'<TD BGCOLOR="{bg_color}" ALIGN="LEFT" BORDER="1">'
+                f'<FONT POINT-SIZE="{theme_config["fonts"]["size"] - 1}">'
+                f'{description or "---"}'
+                f'</FONT>'
+                f'</TD>'
+                f'</TR>'
+            )
+
         return row
 
     def _create_legend_html_table(self) -> str:
